============
Installation
============

At the command line::

    $ easy_install hamsterlib

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv hamsterlib
    $ pip install hamsterlib
